@@ -2,13 +2,13 @@ package LCFG::Build::Skeleton;    # -*-perl-*-
 use strict;
 use warnings;
 
-# $Id: Skeleton.pm.in 26933 2014-12-08 16:08:31Z squinney@INF.ED.AC.UK $
+# $Id: Skeleton.pm.in 27451 2015-02-24 11:16:13Z squinney@INF.ED.AC.UK $
 # $Source: /var/cvs/dice/LCFG-Build-Skeleton/lib/LCFG/Build/Skeleton.pm.in,v $
-# $Revision: 26933 $
-# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Skeleton/LCFG_Build_Skeleton_0_4_1/lib/LCFG/Build/Skeleton.pm.in $
-# $Date: 2014-12-08 16:08:31 +0000 (Mon, 08 Dec 2014) $
+# $Revision: 27451 $
+# $HeadURL: https://svn.lcfg.org/svn/source/tags/LCFG-Build-Skeleton/LCFG_Build_Skeleton_0_5_0/lib/LCFG/Build/Skeleton.pm.in $
+# $Date: 2015-02-24 11:16:13 +0000 (Tue, 24 Feb 2015) $
 
-our $VERSION = '0.4.1';
+our $VERSION = '0.5.0';
 
 use Email::Address ();
 use Email::Valid   ();
@@ -33,6 +33,12 @@ use Moose::Util::TypeConstraints;
 
 with 'MooseX::Getopt';
 
+# This is a little bit of hackery so that the class implements the
+# role but avoids loading the standard role of this name
+
+my $extra_role = Moose::Meta::Role->initialize('MooseX::ConfigFromFile');
+__PACKAGE__->meta->add_role($extra_role);
+
 subtype 'LCFG::Types::ComponentName'
   => as 'Str'
   => where { m/^[A-Za-z][A-Za-z0-9_]+$/ };
@@ -55,12 +61,23 @@ MooseX::Getopt::OptionTypeMap->add_option_type_to_map(
 has 'configfile' => (
     is        => 'ro',
     isa       => 'Str',
-    default   => sub { File::Spec->catfile( $ENV{HOME}, '.lcfg',
-                                            'skeleton', 'defaults.yml' ) },
+    default   => sub {
+        my $class = shift;
+        $class->_get_default_configfile if $class->can('_get_default_configfile');
+    },
     predicate => 'has_configfile',
     documentation => 'Where defaults should be stored',
 );
 
+sub _get_default_configfile {
+    my ($class) = @_;
+
+    my $default = File::Spec->catfile( $ENV{HOME}, '.lcfg',
+                                       'skeleton', 'defaults.yml' );
+
+    return $default;
+}
+
 has 'tmpldir' => (
     is      => 'ro',
     isa     => 'Str',
@@ -69,19 +86,6 @@ has 'tmpldir' => (
     documentation => 'Local templates directory',
 );
 
-has 'usage' => (
-    metaclass => 'NoGetopt',
-    is        => 'ro',
-    isa       => 'Str',
-);
-
-has 'help' => (
-    is            => 'ro',
-    isa           => 'Bool',
-    default       => 0,
-    documentation => 'Display the help text',
-);
-
 has 'name' => (
     is            => 'rw',
     isa           => 'LCFG::Types::ComponentName',
@@ -142,7 +146,7 @@ has 'vcs' => (
     is            => 'rw',
     isa           => enum( [qw/SVN CVS None/] ),
     documentation => 'Version Control System (SVN/CVS/None)',
-    default       => 'CVS',
+    default       => 'SVN',
 );
 
 has 'platforms' => (
@@ -223,66 +227,27 @@ sub get_config_from_file {
     return $cfg;
 }
 
-# The code for new_with_options() is mostly stolen from
-# MooseX::Getopt. It has modifications to allow us to ignore the need
-# to check for a MooseX::ConfigFromFile role. That module just pulls
-# in far too many extra dependencies for our fairly small
-# requirements. This code also handles the default value for the
-# configfile being a code-reference.
-
-sub new_with_options {
-    my ( $class, @params ) = @_;
-
-    my $config_from_file;
-    {
-        local @ARGV = @ARGV;
-
-        my $configfile;
-        my $opt_parser
-            = Getopt::Long::Parser->new( config => [qw(pass_through)] );
-
-        $opt_parser->getoptions( 'configfile=s' => \$configfile );
-
-        if ( !defined $configfile ) {
-            my $cfmeta = $class->meta->find_attribute_by_name('configfile');
-            if ( $cfmeta->has_default ) {
-                $configfile = $cfmeta->default;
-            }
-            if ( 'CODE' eq ref $configfile ) {
-                $configfile = $configfile->();
-            }
-        }
-
-        if ( defined $configfile ) {
-            $config_from_file = $class->get_config_from_file($configfile);
-        }
+sub new_with_config {
+    my ( $class, @args ) = @_;
 
+    my %opts;
+    if ( scalar @args == 1 && ref $args[0] eq 'HASH' ) {
+        %opts = %{$args[0]};
+    } elsif ( @args % 2 == 0 ) {
+        %opts = @args;
     }
 
-    my $constructor_params = ( @params == 1 ? $params[0] : {@params} );
+    my $configfile = delete $opts{configfile};
 
-    if ( ref $constructor_params ne 'HASH' ) {
-        die "Single parameters to new_with_options() must be a HASH ref\n";
+    if ( !defined $configfile && $class->can('_get_default_configfile') ) {
+	$configfile = $class->_get_default_configfile();
     }
 
-    my %processed = $class->_parse_argv(
-        options => [ $class->_attrs_to_options($config_from_file) ],
-        params  => $constructor_params,
-    );
-
-    my $params
-        = $config_from_file
-        ? { %{$config_from_file}, %{ $processed{params} } }
-        : $processed{params};
-
-    return $class->new(
-        ARGV       => $processed{argv_copy},
-        extra_argv => $processed{argv},
-        usage      => "$processed{usage}", # stringify immediately
-        @params,       # explicit params to ->new
-        %{$params},    # params from CLI
-    );
+    if ( defined $configfile ) {
+        %opts = ( %{$class->get_config_from_file($configfile)}, %opts );
+    }
 
+    $class->new(%opts);
 }
 
 my @questions = qw(
@@ -576,7 +541,7 @@ __END__
 
 =head1 VERSION
 
-    This documentation refers to LCFG::Build::Skeleton version 0.4.1
+    This documentation refers to LCFG::Build::Skeleton version 0.5.0
 
 =head1 SYNOPSIS
 
